Bifrost: src/NeighborIterator.hpp File Reference

Bifrost

Data Structures
NeighborIterator.hpp File Reference

The neighborIterator, BackwardCDBG and ForwardCDBG type interfaces. More...

Go to the source code of this file.

## Data Structures
class | CompactedDBG< Unitig_data_t, Graph_data_t >
| Represent a Compacted de Bruijn graph. More...
class | UnitigMap< Unitig_data_t, Graph_data_t, is_const >
| Contain all the information for the mapping of a k-mer or a sequence to a unitig of a Compacted de Bruijn graph. More...
class | neighborIterator< Unitig_data_t, Graph_data_t, is_const >
| Iterator for the neighbors (predecessors or successors) of a reference unitig used in a UnitigMap object. More...
class | BackwardCDBG< Unitig_data_t, Graph_data_t, is_const >
| Wrapper for class neighborIterator to iterate over the predecessors of a reference unitig used in a UnitigMap object. More...
class | ForwardCDBG< Unitig_data_t, Graph_data_t, is_const >
| Wrapper for class neighborIterator to iterate over the predecessors of a reference unitig used in a UnitigMap object. More...

## Detailed Description

The neighborIterator, BackwardCDBG and ForwardCDBG type interfaces.

Code snippets using these interfaces are provided in snippets/test.cpp.